@@ -48,4 +48,8 @@ class Providers:
         return bool(self.results)
 
     def __getitem__(self, region: str) -> ProviderData:
-        return getattr(self.results, region.upper(), ProviderData())
+        return getattr(
+            self.results,
+            region.upper(),
+            ProviderData(buy=[], flatrate=[], free=[], link=None),
+        )
